@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-01-09'; # DATE
-our $VERSION = '0.76'; # VERSION
+our $DATE = '2015-01-10'; # DATE
+our $VERSION = '0.77'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -350,6 +350,7 @@ sub run_call {
 
     my %extra;
     if ($r->{send_argv}) {
+        $log->tracef("[pericmd] Sending argv to server: %s", $extra{argv});
         $extra{argv} = $r->{orig_argv};
     } else {
         $extra{args} = $r->{args};
@@ -357,8 +358,13 @@ sub run_call {
 
     $extra{stream_arg} = 1 if $r->{stream_arg};
 
+    my $url = $r->{subcommand_data}{url};
+
+    # currently we don't log args because it's potentially large
+    $log->tracef("[pericmd] Riap request: action=call, url=%s", $url);
+
     $self->riap_client->request(
-        call => $r->{subcommand_data}{url}, \%extra);
+        call => $url, \%extra);
 }
 
 1;
@@ -376,7 +382,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.76 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-01-09.
+This document describes version 0.77 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-01-10.
 
 =head1 SYNOPSIS
 
@@ -563,7 +569,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
